@@ -51,6 +51,8 @@ EBImoran.mc <- function (n, x, listw, nsim, zero.policy = FALSE,
         pval <- punif((diff + 1)/(nsim + 1), lower.tail=FALSE)
     else if (alternative == "greater") 
         pval <- punif((diff + 1)/(nsim + 1))
+    if (pval < 0 || pval > 1) 
+	warning("Out-of-range p-value: reconsider test arguments")
     statistic <- res[nsim + 1]
     names(statistic) <- "statistic"
     parameter <- zrank
